import { applyTransform } from '@codeshift/test-utils';
import * as transformer from './transform';

describe('button@5.0.0 transform', () => {
  describe('IconButton component', () => {
    it('should transform ariaLabel from PascalCase to param-case if string literal is used', async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton ariaLabel="Label" />',
      );
      expect(result).toBe('<IconButton aria-label="Label" />');
    });
    it("should transform ariaLabel from PascalCase to param-case if string literal isn't used", async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton ariaLabel={obj} />',
      );
      expect(result).toBe('<IconButton aria-label={obj} />');
    });
    it('should replace buttonState "enabled" with "default"', async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton buttonState="enabled" />',
      );
      expect(result).toBe('<IconButton buttonState="default" />');
    });
    it('shouldn\'t replace buttonState "disabled"', async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton buttonState="disabled" />',
      );
      expect(result).toBe('<IconButton buttonState="disabled" />');
    });
    it('shouldn\'t replace buttonState "loading"', async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton buttonState="loading" />',
      );
      expect(result).toBe('<IconButton buttonState="loading" />');
    });
    it('should replace variant "primary" with "emphasized"', async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton variant="primary" />',
      );
      expect(result).toBe('<IconButton variant="emphasized" />');
    });
    it('shouldn\'t replace variant "default"', async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton variant="default" />',
      );
      expect(result).toBe('<IconButton variant="default" />');
    });
    it('shouldn\'t replace variant "critical"', async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton variant="critical" />',
      );
      expect(result).toBe('<IconButton variant="critical" />');
    });
    it('shouldn\'t replace variant "success"', async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton variant="success" />',
      );
      expect(result).toBe('<IconButton variant="success" />');
    });
    it('shouldn\'t replace variant "tertiary"', async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton variant="tertiary" />',
      );
      expect(result).toBe('<IconButton variant="tertiary" />');
    });
    it("shouldn't replace buttonState if string literal isn't used", async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton buttonState={obj} />',
      );
      expect(result).toBe('<IconButton buttonState={obj} />');
    });
    it('should replace theme "primary" with variant "emphasized"', async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton theme="primary" />',
      );
      expect(result).toBe('<IconButton variant="emphasized" />');
    });
    it('should replace theme "default" with variant "default"', async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton theme="default" />',
      );
      expect(result).toBe('<IconButton variant="default" />');
    });
    it('shouldn\'t replace theme "critical"', async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton theme="critical" />',
      );
      expect(result).toBe('<IconButton theme="critical" />');
    });
    it('shouldn\'t replace theme "success"', async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton theme="success" />',
      );
      expect(result).toBe('<IconButton theme="success" />');
    });
    it('shouldn\'t replace theme "tertiary"', async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton theme="tertiary" />',
      );
      expect(result).toBe('<IconButton theme="tertiary" />');
    });
    it('shouldn\'t replace theme "default" with variant "default" if string literal isn\'t used', async () => {
      const result = await applyTransform(
        transformer,
        '<IconButton theme={obj} />',
      );
      expect(result).toBe('<IconButton theme={obj} />');
    });
  });

  describe('Button component', () => {
    it('should replace buttonState "enabled" with "default"', async () => {
      const result = await applyTransform(
        transformer,
        '<Button buttonState="enabled" />',
      );
      expect(result).toBe('<Button buttonState="default" />');
    });
    it('shouldn\'t replace buttonState "disabled"', async () => {
      const result = await applyTransform(
        transformer,
        '<Button buttonState="disabled" />',
      );
      expect(result).toBe('<Button buttonState="disabled" />');
    });
    it('shouldn\'t replace buttonState "loading"', async () => {
      const result = await applyTransform(
        transformer,
        '<Button buttonState="loading" />',
      );
      expect(result).toBe('<Button buttonState="loading" />');
    });
    it('shouldn\'t replace buttonState "enabled" with "default" if string literal isn\'t used', async () => {
      const result = await applyTransform(
        transformer,
        '<Button buttonState={obj} />',
      );
      expect(result).toBe('<Button buttonState={obj} />');
    });

    it('shouldn\'t replace variant "default"', async () => {
      const result = await applyTransform(
        transformer,
        '<Button variant="default" />',
      );
      expect(result).toBe('<Button variant="default" />');
    });

    it('should replace variant "primary" with variant="emphasized" and tone="default"', async () => {
      const result = await applyTransform(
        transformer,
        '<Button variant="primary" />',
      );
      expect(result).toBe('<Button variant="emphasized" tone="default" />');
    });

    it('should replace variant "critical" with variant="emphasized" and tone="critical"', async () => {
      const result = await applyTransform(
        transformer,
        '<Button variant="critical" />',
      );
      expect(result).toBe('<Button variant="emphasized" tone="critical" />');
    });
    it('should replace variant "success" with variant="emphasized" and tone="success"', async () => {
      const result = await applyTransform(
        transformer,
        '<Button variant="success" />',
      );
      expect(result).toBe('<Button variant="emphasized" tone="success" />');
    });
    it('should replace variant "tertiary" with variant="plain"', async () => {
      const result = await applyTransform(
        transformer,
        '<Button variant="tertiary" />',
      );
      expect(result).toBe('<Button variant="plain" />');
    });
    it('shouldn\'t replace variant "tertiary" with variant="plain" if string literal isn\'t used', async () => {
      const result = await applyTransform(
        transformer,
        '<Button variant={obj} />',
      );
      expect(result).toBe('<Button variant={obj} />');
    });
    it('should replace theme "default" with variant "default"', async () => {
      const result = await applyTransform(
        transformer,
        '<Button theme="default" />',
      );
      expect(result).toBe('<Button variant="default" />');
    });

    it('should replace theme "primary" with variant="emphasized" and tone="default"', async () => {
      const result = await applyTransform(
        transformer,
        '<Button theme="primary" />',
      );
      expect(result).toBe('<Button variant="emphasized" tone="default" />');
    });

    it('should replace theme "critical" with variant="emphasized" and tone="critical"', async () => {
      const result = await applyTransform(
        transformer,
        '<Button theme="critical" />',
      );
      expect(result).toBe('<Button variant="emphasized" tone="critical" />');
    });
    it('should replace theme "success" with variant="emphasized" and tone="success"', async () => {
      const result = await applyTransform(
        transformer,
        '<Button theme="success" />',
      );
      expect(result).toBe('<Button variant="emphasized" tone="success" />');
    });
    it('should replace theme "tertiary" with variant="plain"', async () => {
      const result = await applyTransform(
        transformer,
        '<Button theme="tertiary" />',
      );
      expect(result).toBe('<Button variant="plain" />');
    });
    it('should replace theme with variant', async () => {
      const result = await applyTransform(
        transformer,
        '<Button theme={obj} />',
      );
      expect(result).toBe('<Button variant={obj} />');
    });
  });
});
